<%@ Language = VBSCRIPT %>
<% Option Explicit %>

<%
   '*************************************************
   'Display a calendar based upon the current date
   '*************************************************

   'To accomplish this, we need to perform a number of tasks.
   'First, we will want to be able to determine the month name
   'for a given month.  So, let's create a function that
   'takes the numeric value of a month and displays the name of
   'the month (i.e., GetMonthName(8) would output August)
   Function GetMonthName(iMonth)
     Select Case iMonth
        Case 1:
          GetMonthName = "January"
        Case 2:
          GetMonthName = "February"
        Case 3:
          GetMonthName = "March"
        Case 4:
          GetMonthName = "April"
        Case 5:
          GetMonthName = "May"
        Case 6:
          GetMonthName = "June"
        Case 7:
          GetMonthName = "July"
        Case 8:
          GetMonthName = "August"
        Case 9:
          GetMonthName = "September"
        Case 10:
          GetMonthName = "October"
        Case 11:
          GetMonthName = "November"
        Case 12:
          GetMonthName = "December"
        Case Else:
          GetMonthName = "**INVALID MONTH**"
     End Select
   End Function


   'Next, we need to obtain the date passed through the
   'QueryString.  To do this, we need to use the Request
   'object, reading in the Date variable from the QueryString
   Dim dbCurrentDate
   dbCurrentDate = Request("Date")

   'Create a cookie so that we can remember the last month.  If a date has
   'been specified, set the cookie to the value, else read a cookie to
   'determine what date the user is interested in seeing.  If no date was passed
   'in, Len(dbCurrentDate) will equal 0, since dbCurrentDate will be equal to
   'a blank string.
   If Len(dbCurrentDate) = 0 then
     'Read in the value of the cookie
     dbCurrentDate = Request.Cookies("CalendarDate")
   End If

   'Check to make sure that dbCurrentDate equals a value.  If Date was not
   'passed through the querystring or assigned a cookie value, dbCurrentDate
   'will be an empty string.
   If Len(dbCurrentDate) = 0 then
     'Date was not passed through the QueryString - set dbCurrentDate to
     'the current system date
     dbCurrentDate = Date()
   End If

   'At this point, we are certain that dbCurrentDate equals a valid date.  If
   'the Date was not passed in through the Querystring, we assigned
   'dbCurrentDate to the cookie on the client's computer which represents the
   'last calendar date viewed.  If no cookie existed, we set dbCurrentDate to
   'the current system date.  Now we need to write to our cookie, setting it
   'equal to dbCurrentDate
   Response.Cookies("CalendarDate") = dbCurrentDate

   'Set the cookie to expire in 30 days
   Response.Cookies("CalendarDate").Expires = Now() + 30


   'Now that we have the Date we're interested in viewing, we need to
   'Grab the events from the database that correspond to the month and
   'year of dbCurrentDate.  We'll begin by creating our Connection object
   Dim objConn
   Set objConn = Server.CreateObject("ADODB.Connection")
   objConn.ConnectionString = "DSN=CalendarEvents"
   objConn.Open

   'Now, we need to create our recordset object, grabbing all of the
   'events whose Month column equals Month(dbCurrentDate) and whose
   'Year column equals Year(dbCurrentDate).  We'll use a SQL statement
   'to accomplish this, since there may be many records in the Event table
   Dim strSQL
   strSQL = "SELECT Day, EventTitle FROM Event WHERE Month = " & _
            Month(dbCurrentDate) & " AND Year = " & Year(dbCurrentDate) & _
            " ORDER BY Day ASC"

   'Now, we need to create and open our recordset object.  We can use a
   'forward-only cursor and read only lock, so we'll simply not specify
   'them, since they are the default
   Dim objRS
   Set objRS = Server.CreateObject("ADODB.Recordset")
   objRS.Open strSQL, objConn


   'Now, we need to display a calendar.  At most, a calendar
   'can have six weeks.  Since a week contains seven days,
   'we will show, at most, 42 calendar cells.  We will use
   'a TABLE to generate this calendar

   'We will create an array that will store the 42 possible
   'days of the month.
   Dim aCalendarDays(42)

   'Into aCalendarDays, we will place the days of the current
   'month.  We will use the DatePart function to determine
   'when the first day of the month is
   Dim iFirstWeekday
   iFirstWeekday = DatePart("w",DateSerial(Year(dbCurrentDate), Month(dbCurrentDate), 1))

   'Now, we want to loop from 1 to the number of days in the
   'current month, populating the array aCalendarDays
   Dim iDaysInMonth
   iDaysInMonth = DatePart("d",DateSerial(Year(dbCurrentDate), Month(dbCurrentDate)+1, 1-1))
   Dim iLoop
   For iLoop = 1 to iDaysInMonth
      aCalendarDays(iLoop + iFirstWeekday - 1) = iLoop
   Next


   'Now that we have our populated array, we need to display the
   'array in calendar form.  We will create a table of 7 columns,
   'one for each day of the week.  The number of rows we will use
   'will be 6, the total number of possible rows, minus 42 (the upper 
   'bound of the aCalendarDays array) minus the last array position
   'used (iFirstWeekday + iDaysInMonth) divided by seven, the number of
   'days in the week!  Simple, eh!!  :)
   Dim iColumns, iRows
   iColumns = 7
   iRows = 6 - Int((42 - (iFirstWeekDay + iDaysInMonth)) / 7)


   'Store the next and previous months, Using Server.URLEncode to make
   'sure the values can be safely passed through the QueryString
   Dim strPrevMonth, strNextMonth
   strPrevMonth = Server.URLEncode(DateAdd("m", -1, dbCurrentDate))
   strNextMonth = Server.URLEncode(DateAdd("m", 1, dbCurrentDate))

   'Now, create the table
%>

<HTML>
<BODY>
   <TABLE ALIGN=CENTER BORDER=1 CELLSPACING=1 WIDTH=75% HEIGHT=75%>
   <TR>
     <TH>
        <A HREF="Calendar.asp?Date=<%=strPrevMonth%>">
             View the Previous Month
        </A>
     </TH>

     <TH COLSPAN=5>
        <FONT SIZE=+2>
<%
   'Display the month and year
   Response.Write GetMonthName(Month(dbCurrentDate))
   Response.Write ", " & Year(dbCurrentDate)
%>
        </FONT>
     </TH>

     <TH>
        <A HREF="Calendar.asp?Date=<%=strNextMonth%>">
             View the Next Month
        </A>
     </TH>
    </TR>

<%
   'Keep track of how many events we display
   Dim iEventCount
   iEventCount = 0

   'Now, loop through 1 through iRows, then 1 through iColumns
   Dim iRowsLoop, iColumnsLoop
   For iRowsLoop = 1 to iRows
     'Create a new row
     Response.Write "<TR>"
     For iColumnsLoop = 1 to iColumns
       'Create a new column
       'If there is a day there, display it, else black out the cell
       If aCalendarDays((iRowsLoop-1)*7 + iColumnsLoop) > 0 then
         'Display the date, and determine whether or not there is
         'an event in the database for this date
         Response.Write "<TD VALIGN=TOP ALIGN=RIGHT WIDTH=14% " & _
                         "HEIGHT=" & FormatPercent(1/iRows,0) & ">"
         Response.Write "<TABLE CELLSPACING=0 CELLPADDING=0 BORDER=0 " & _
                        "WIDTH=""100%"">"

         'Write the day in the upper-right hand corner
         Response.Write "<TR><TD ALIGN=RIGHT><B>"
         Response.Write aCalendarDays((iRowsLoop-1)*7 + iColumnsLoop)
         Response.Write "</B></TD></TR>"

         'Write the calendar event for that day, if it exists
         'First check to make sure objRS is not at the end of file
         If Not objRS.EOF then
            'Now, check to see if the current record contains the
            'current date for its day column
            If objRS("Day") = aCalendarDays((iRowsLoop-1)*7 + iColumnsLoop) then
               Response.Write "<TR><TD VALIGN=TOP ALIGN=LEFT>"
               Response.Write "<FONT SIZE=2>"

               Response.Write objRS("EventTitle")
               objRS.MoveNext

               'Increment how many Events we're showing
               iEventCount = iEventCount + 1

               Response.Write "</FONT>"
               Response.Write "</TD></TR>"
            End If
         End If
         
         Response.Write "</TABLE>"
         Response.Write "</TD>"
       Else
         'Black out the cell
         Response.Write "<TD BGCOLOR=BLACK>&nbsp;</TD>"
       End If
     Next

     'Close the row
     Response.Write "</TR>"
   Next


   'We can close and explicitly free our recordset and connection
   'objects now!
   objRS.Close
   Set objRS = Nothing

   objConn.Close
   Set objConn = Nothing
%>

   </TABLE>

   <CENTER>
   <FONT SIZE=2>
      <%=FormatNumber(iEventCount,0)%> Events in <%=GetMonthName(Month(dbCurrentDate))%>,
      <%=Year(dbCurrentDate)%>
   </FONT>
   </CENTER>

   <P>
   <FORM METHOD=GET ACTION="Calendar.asp">
     <CENTER><B>View a Specific Month</B><BR>
     <SELECT SIZE=1 NAME=Date>
        <OPTION VALUE="<%=DateSerial(Year(dbCurrentDate), 1, 1)%>"
          <% If Month(dbCurrentDate) = 1 then Response.Write " SELECTED" %>>
           January
        </OPTION>
        <OPTION VALUE="<%=DateSerial(Year(dbCurrentDate), 2, 1)%>"
          <% If Month(dbCurrentDate) = 2 then Response.Write " SELECTED" %>>
           February
        </OPTION>
        <OPTION VALUE="<%=DateSerial(Year(dbCurrentDate), 3, 1)%>"
          <% If Month(dbCurrentDate) = 3 then Response.Write " SELECTED" %>>
           March
        </OPTION>
        <OPTION VALUE="<%=DateSerial(Year(dbCurrentDate), 4, 1)%>"
          <% If Month(dbCurrentDate) = 4 then Response.Write " SELECTED" %>>
           April
        </OPTION>
        <OPTION VALUE="<%=DateSerial(Year(dbCurrentDate), 5, 1)%>"
          <% If Month(dbCurrentDate) = 5 then Response.Write " SELECTED" %>>
           May
        </OPTION>
        <OPTION VALUE="<%=DateSerial(Year(dbCurrentDate), 6, 1)%>"
          <% If Month(dbCurrentDate) = 6 then Response.Write " SELECTED" %>>
           June
        </OPTION>
        <OPTION VALUE="<%=DateSerial(Year(dbCurrentDate), 7, 1)%>"
          <% If Month(dbCurrentDate) = 7 then Response.Write " SELECTED" %>>
           July
        </OPTION>
        <OPTION VALUE="<%=DateSerial(Year(dbCurrentDate), 8, 1)%>"
          <% If Month(dbCurrentDate) = 8 then Response.Write " SELECTED" %>>
           August
        </OPTION>
        <OPTION VALUE="<%=DateSerial(Year(dbCurrentDate), 9, 1)%>"
          <% If Month(dbCurrentDate) = 9 then Response.Write " SELECTED" %>>
           September
        </OPTION>
        <OPTION VALUE="<%=DateSerial(Year(dbCurrentDate), 10, 1)%>"
          <% If Month(dbCurrentDate) = 10 then Response.Write " SELECTED" %>>
           October
        </OPTION>
        <OPTION VALUE="<%=DateSerial(Year(dbCurrentDate), 11, 1)%>"
          <% If Month(dbCurrentDate) = 11 then Response.Write " SELECTED" %>>
           November
        </OPTION>
        <OPTION VALUE="<%=DateSerial(Year(dbCurrentDate), 12, 1)%>"
          <% If Month(dbCurrentDate) = 12 then Response.Write " SELECTED" %>>
           December
        </OPTION>
      </SELECT>
      <BR>
      <INPUT TYPE=SUBMIT VALUE="View Select Month">
    </FORM>
    </CENTER>
</BODY>
</HTML>